@@ -273,7 +273,7 @@ async def full_outer_union(
     await right.aclose()
 
 
-async def limited(limit: int, it: AsyncGenerator[T, None]) -> AsyncGenerator[T, None]:
+async def take(limit: int, it: AsyncGenerator[T, None]) -> AsyncGenerator[T, None]:
     i = 0
     async for r in it:
         if i >= limit:
@@ -282,6 +282,9 @@ async def limited(limit: int, it: AsyncGenerator[T, None]) -> AsyncGenerator[T,
         i += 1
 
 
+limited = take
+
+
 async def filter(
     func: Union[Callable[[Any], bool], None], it: AsyncGenerator[T, None]
 ) -> AsyncGenerator[T, None]:
